package com.bonus.hn.bearing.capacity.backstage.companypro.dao;

import com.bonus.hn.bearing.capacity.backstage.companypro.entity.ProjectManagerBean;
import com.bonus.hn.bearing.capacity.backstage.companypro.entity.TreeBean;
import com.bonus.hn.bearing.capacity.backstage.select.entity.SelectBean;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 包名称：com.bonus.hn.bearing.capacity.backstage.companypro.dao
 * 类名称：ProjectManagerDao
 * 类描述：
 * 创建人：@author xxxxxx
 * 创建时间：2023年11月06日 16:26
 */
@Repository(value = "ProjectManagerDao")
public interface ProjectManagerDao {
    List<ProjectManagerBean>  getProjectManagerTeamsList(ProjectManagerBean o);

    List<SelectBean> getBranchName(SelectBean o);

    List<SelectBean> getVoltageLevel(SelectBean o);

    List<SelectBean> getProName(SelectBean o);

    List<SelectBean> getTeamType(SelectBean o);

    List<ProjectManagerBean> getProjectManagementTeamsFormList(ProjectManagerBean o);

    List<ProjectManagerBean> getProManageTeamNum(ProjectManagerBean o);

    int determineIfExists(ProjectManagerBean bean);

    int addProManageTeam(ProjectManagerBean bean);

    int updateProManageTeam(ProjectManagerBean bean);

    int insertProManageTeam(ProjectManagerBean bean);

    void updateProManage(ProjectManagerBean bean);

    int deleteProManageTeam(ProjectManagerBean bean);

    List<TreeBean> getCompanyProTree(TreeBean o);

    List<ProjectManagerBean> getTeamsList(ProjectManagerBean o);

    int bindProTeam(ProjectManagerBean bean);

    int unBindProTeam(ProjectManagerBean bean);

    int updateStatus(ProjectManagerBean bean);

    int delProTeamPersonById(ProjectManagerBean bean);

    List<SelectBean> getProjectName(SelectBean o);

    List<SelectBean> getEngineerLevel(SelectBean o);

    List<SelectBean> getBearingCapacity(SelectBean o);

    List<SelectBean> getRealNameSystem(SelectBean o);

    int getIsExistRelationship(ProjectManagerBean bean);

    List<ProjectManagerBean> getProPersonList(ProjectManagerBean o);
}
